.. include:: ../README.rst

Table of Contents
=================

.. toctree::
    :maxdepth: 4
    :hidden:

    self

.. toctree::
    :caption: Examples

    examples

.. toctree::
    :caption: API Reference
    :maxdepth: 3

    api

.. toctree::
    :caption: Tutorials

    Adafruit Light Meter Learning guide <https://learn.adafruit.com/light-meter>

    Adafruit i2c/SPI LCD Backpack Learning Guide <https://learn.adafruit.com/i2c-spi-lcd-backpack>

    Adafruit i2c / SPI character LCD backpack Learning Guide <https://learn.adafruit.com/character-lcds>

    Adafruit RGB LCD Shield Kit w/ 16x2 Character Display Learning Guide <https://learn.adafruit.com/rgb-lcd-shield>

    Adafruit RGB Positive 16x2 LCD+Keypad Kit for Raspberry Pi Learning Guide <https://learn.adafruit.com/adafruit-16x2-character-lcd-plus-keypad-for-raspberry-pi>

.. toctree::
    :caption: Related Products

    Standard LCD 16x2 + extras - white on blue <https://www.adafruit.com/product/181>

    Adafruit Standard LCD 20x4 + extras - white on blue <https://www.adafruit.com/product/198>

    Adafruit Character LCDs <http://www.adafruit.com/category/63_96>

    Adafruit i2c / SPI character LCD backpack <https://www.adafruit.com/product/292>

    Adafruit RGB backlight negative LCD 16x2 + extras - RGB on black <https://www.adafruit.com/product/399>

    Adafruit RGB LCD Shield Kit w/ 16x2 Character Display <https://www.adafruit.com/product/716>

    Adafruit RGB Positive 16x2 LCD+Keypad Kit for Raspberry Pi <https://www.adafruit.com/product/1109>

    Adafruit RGB Negative 16x2 LCD+Keypad Kit for Raspberry Pi <https://www.adafruit.com/product/1110>


.. toctree::
    :caption: Other Links

    Download <https://github.com/adafruit/Adafruit_CircuitPython_CharLCD/releases/latest>
    CircuitPython Reference Documentation <https://docs.circuitpython.org>
    CircuitPython Support Forum <https://forums.adafruit.com/viewforum.php?f=60>
    Discord Chat <https://adafru.it/discord>
    Adafruit Learning System <https://learn.adafruit.com>
    Adafruit Blog <https://blog.adafruit.com>
    Adafruit Store <https://www.adafruit.com>

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
